@@ -86,7 +86,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56000
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -181,6 +181,12 @@
 #else
 #  define KRUNNER_DEPRECATED_VERSION_5_88(text)
 #endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x56300
+#  define KRUNNER_DEPRECATED_VERSION_5_99(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_99(text)
+#endif
 #define KRUNNER_DEPRECATED_VERSION_5(minor, text)      KRUNNER_DEPRECATED_VERSION_5_##minor(text)
 #define KRUNNER_DEPRECATED_VERSION(major, minor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KRUNNER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
@@ -246,7 +252,7 @@
 #define KRUNNER_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KRUNNER_NO_DEPRECATED
-#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
+#  define KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56500
 #endif
 #ifdef KRUNNER_NO_DEPRECATED_WARNINGS
 #  define KRUNNER_DEPRECATED_WARNINGS_SINCE 0
@@ -256,7 +262,7 @@
 #  ifdef KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KRUNNER_DEPRECATED_WARNINGS_SINCE KRUNNER_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56000
+#    define KRUNNER_DEPRECATED_WARNINGS_SINCE 0x56500
 #  endif
 #endif
 
@@ -341,6 +347,12 @@
 #else
 #  define KRUNNER_DEPRECATED_VERSION_5_88(text)
 #endif
+
+#if KRUNNER_DEPRECATED_WARNINGS_SINCE >= 0x56300
+#  define KRUNNER_DEPRECATED_VERSION_5_99(text) KRUNNER_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KRUNNER_DEPRECATED_VERSION_5_99(text)
+#endif
 #define KRUNNER_DEPRECATED_VERSION_5(minor, text)      KRUNNER_DEPRECATED_VERSION_5_##minor(text)
 #define KRUNNER_DEPRECATED_VERSION(major, minor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KRUNNER_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KRUNNER_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
